@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -16,23 +16,26 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-// Filter that does nothing. Use as sru_to_z3950 for new filters 
 #ifndef FILTER_SRU_TO_Z3950_HPP
 #define FILTER_SRU_TO_Z3950_HPP
 
 #include <boost/scoped_ptr.hpp>
+#include <boost/shared_ptr.hpp>
 
 #include <metaproxy/filter.hpp>
 
 namespace metaproxy_1 {
     namespace filter {
         class SRUtoZ3950 : public Base {
+            class Frontend;
             class Impl;
             boost::scoped_ptr<Impl> m_p;
+            typedef boost::shared_ptr<Frontend> FrontendPtr;
         public:
             SRUtoZ3950();
             ~SRUtoZ3950();
-            void configure(const xmlNode *xmlnode, bool test_only);
+            void configure(const xmlNode *xmlnode, bool test_only,
+                           const char *path);
             void process(metaproxy_1::Package & package) const;
         };
     }
